==> kubernetes-model-networking-5.7.3-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicySpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkPolicySpecFluent<A extends io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEgress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public A setToEgress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public A addToEgress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule... items);
  public A addAllToEgress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> items);
  public A removeFromEgress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule... items);
  public A removeAllFromEgress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> items);
  public A removeMatchingFromEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEgress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> getEgress();
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> buildEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildEgress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildFirstEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildLastEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildMatchingEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  public A withEgress(java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> egress);
  public A withEgress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule... egress);
  public java.lang.Boolean hasEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> addNewEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> addNewEgressLike(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> setNewEgressLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editEgress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editFirstEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editLastEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editMatchingEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  public A addToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public A setToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public A addToIngress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule... items);
  public A addAllToIngress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> items);
  public A removeFromIngress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule... items);
  public A removeAllFromIngress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> items);
  public A removeMatchingFromIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> getIngress();
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> buildIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildFirstIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildLastIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  public A withIngress(java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> ingress);
  public A withIngress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule... ingress);
  public java.lang.Boolean hasIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> addNewIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> addNewIngressLike(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> setNewIngressLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editFirstIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editLastIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPodSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getPodSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildPodSelector();
  public A withPodSelector(io.fabric8.kubernetes.api.model.LabelSelector podSelector);
  public java.lang.Boolean hasPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> withNewPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> withNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> editPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> editOrNewPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> editOrNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToPolicyTypes(java.lang.Integer index,java.lang.String item);
  public A setToPolicyTypes(java.lang.Integer index,java.lang.String item);
  public A addToPolicyTypes(java.lang.String... items);
  public A addAllToPolicyTypes(java.util.Collection<java.lang.String> items);
  public A removeFromPolicyTypes(java.lang.String... items);
  public A removeAllFromPolicyTypes(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getPolicyTypes();
  public java.lang.String getPolicyType(java.lang.Integer index);
  public java.lang.String getFirstPolicyType();
  public java.lang.String getLastPolicyType();
  public java.lang.String getMatchingPolicyType(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingPolicyType(java.util.function.Predicate<java.lang.String> predicate);
  public A withPolicyTypes(java.util.List<java.lang.String> policyTypes);
  public A withPolicyTypes(java.lang.String... policyTypes);
  public java.lang.Boolean hasPolicyTypes();
  public A addNewPolicyType(java.lang.String arg0);
  public interface EgressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<N>>{
    public N and();
    public N endEgress();
    
  }
  public interface IngressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  public interface PodSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<N>>{
    public N and();
    public N endPodSelector();
    
  }
  
}

==> kubernetes-model-networking-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/networking/v1/NetworkPolicySpecFluent.java <==
package io.fabric8.kubernetes.api.model.networking.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonInclude;
import io.fabric8.kubernetes.api.builder.Nested;
import java.util.ArrayList;
import java.lang.String;
import java.util.LinkedHashMap;
import java.util.function.Predicate;
import java.lang.Deprecated;
import java.util.Iterator;
import java.util.List;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.LabelSelectorBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.model.LabelSelector;
import java.lang.Integer;
import java.util.Collection;
import java.lang.Object;
import io.fabric8.kubernetes.api.model.LabelSelectorFluent;
import java.util.Map;

 /**
  * Generated
  */
public interface NetworkPolicySpecFluent<A extends io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent<A>> extends io.fabric8.kubernetes.api.builder.Fluent<A>{
  public A addToEgress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public A setToEgress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public A addToEgress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule... items);
  public A addAllToEgress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> items);
  public A removeFromEgress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule... items);
  public A removeAllFromEgress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> items);
  public A removeMatchingFromEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildEgress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> getEgress();
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> buildEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildEgress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildFirstEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildLastEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule buildMatchingEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  public A withEgress(java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule> egress);
  public A withEgress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule... egress);
  public java.lang.Boolean hasEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> addNewEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> addNewEgressLike(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> setNewEgressLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editEgress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editFirstEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editLastEgress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<A> editMatchingEgress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleBuilder> predicate);
  public A addToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public A setToIngress(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public A addToIngress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule... items);
  public A addAllToIngress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> items);
  public A removeFromIngress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule... items);
  public A removeAllFromIngress(java.util.Collection<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> items);
  public A removeMatchingFromIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildIngress instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> getIngress();
  public java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> buildIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildFirstIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildLastIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule buildMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  public java.lang.Boolean hasMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  public A withIngress(java.util.List<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule> ingress);
  public A withIngress(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule... ingress);
  public java.lang.Boolean hasIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> addNewIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> addNewIngressLike(io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> setNewIngressLike(java.lang.Integer index,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRule item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editIngress(java.lang.Integer index);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editFirstIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editLastIngress();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<A> editMatchingIngress(java.util.function.Predicate<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleBuilder> predicate);
  
  /**
   * This method has been deprecated, please use method buildPodSelector instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.LabelSelector getPodSelector();
  public io.fabric8.kubernetes.api.model.LabelSelector buildPodSelector();
  public A withPodSelector(io.fabric8.kubernetes.api.model.LabelSelector podSelector);
  public java.lang.Boolean hasPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> withNewPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> withNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> editPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> editOrNewPodSelector();
  public io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<A> editOrNewPodSelectorLike(io.fabric8.kubernetes.api.model.LabelSelector item);
  public A addToPolicyTypes(java.lang.Integer index,java.lang.String item);
  public A setToPolicyTypes(java.lang.Integer index,java.lang.String item);
  public A addToPolicyTypes(java.lang.String... items);
  public A addAllToPolicyTypes(java.util.Collection<java.lang.String> items);
  public A removeFromPolicyTypes(java.lang.String... items);
  public A removeAllFromPolicyTypes(java.util.Collection<java.lang.String> items);
  public java.util.List<java.lang.String> getPolicyTypes();
  public java.lang.String getPolicyType(java.lang.Integer index);
  public java.lang.String getFirstPolicyType();
  public java.lang.String getLastPolicyType();
  public java.lang.String getMatchingPolicyType(java.util.function.Predicate<java.lang.String> predicate);
  public java.lang.Boolean hasMatchingPolicyType(java.util.function.Predicate<java.lang.String> predicate);
  public A withPolicyTypes(java.util.List<java.lang.String> policyTypes);
  public A withPolicyTypes(java.lang.String... policyTypes);
  public java.lang.Boolean hasPolicyTypes();
  public A addNewPolicyType(java.lang.String arg0);
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value);
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public A removeFromAdditionalProperties(java.lang.String key);
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map);
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties);
  public java.lang.Boolean hasAdditionalProperties();
  public interface EgressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyEgressRuleFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.EgressNested<N>>{
    public N and();
    public N endEgress();
    
  }
  public interface IngressNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicyIngressRuleFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.IngressNested<N>>{
    public N and();
    public N endIngress();
    
  }
  public interface PodSelectorNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,io.fabric8.kubernetes.api.model.LabelSelectorFluent<io.fabric8.kubernetes.api.model.networking.v1.NetworkPolicySpecFluent.PodSelectorNested<N>>{
    public N and();
    public N endPodSelector();
    
  }
  
}
